powered by
Calculate FDR-adjusted p-values.
call_fdr(whole_re, thres_tr = 10, method = 'BH')
A list of the objects obtained from sharpr2 for each chromosome.
The threshold for the size of tiled reigons used for calculate FDR-adjusted p-values. The default value is 10.
The method for calculating FDR-adjusted p-values. See the function 'p.adjust' for more details abount the method. The default is 'BH'.
gfdr: a result table (data.frame) containing FDR-adjusted p-values, chromosome, region, the size and the index of the tiled region it is located.
# NOT RUN { # } # NOT RUN { data(hidra_ex) whole_re <- sharpr2(hidra_ex, l_min = 150, l_max = 600, f_dna = 5, f_rna = 0, sig=FALSE) call_fdr(list(whole_re)) # } # NOT RUN { # }
Run the code above in your browser using DataLab