Given an object returned from the sharpr2 function, this function calls significant regions that contain driver elements for a specific tiled region based on a user-defined threshold.
Usage
call_sig_reg(res, nr, threshold = 3.5, win = 10)
Arguments
res
An object obtained from the sharpr2 function.
nr
An integer indicating the number of tiled region in res for which driver elements will be called.
threshold
The cutoff to identify driver elements in the tiled region. The positions with a z-score larger than the threshold will be called. The default is 3.5.
win
A window size for removing sporadic significant regions. If a significant consecutive region is small than win, it will be treated as false signals. The default is 10.
Value
sig_reg: identified regions containing driver elements.