Learn R Programming

sharpr2 (version 1.1.1.0)

find_reg: find_reg

Description

Given an object from sharpr2 and a position, this function finds the tiled region containing the position.

Usage

find_reg(re,pos)

Arguments

re

An object obtained from sharpr2.

pos

A position for which the tiled region is searched.

Value

ind: the index of the tiled region in the object from sharpr2. If no such tile region is found, NA is returned.

Examples

Run this code
# NOT RUN {
data(hidra_ex)
re <- sharpr2(hidra_ex[1:2000,], l_min = 150, l_max = 600, f_dna = 5, f_rna = 0, sig=FALSE)
find_reg(re,1000000)
# }

Run the code above in your browser using DataLab