powered by
Given an object from sharpr2 and a position, this function finds the tiled region containing the position.
find_reg(re,pos)
An object obtained from sharpr2.
A position for which the tiled region is searched.
ind: the index of the tiled region in the object from sharpr2. If no such tile region is found, NA is returned.
# NOT RUN { data(hidra_ex) re <- sharpr2(hidra_ex[1:2000,], l_min = 150, l_max = 600, f_dna = 5, f_rna = 0, sig=FALSE) find_reg(re,1000000) # }
Run the code above in your browser using DataLab